# ------------------------------------------------------------------------
# RF-DETR+
# Copyright (c) 2026 Roboflow, Inc. All Rights Reserved.
# Licensed under the Platform Model License 1.0 [see LICENSE for details]
# ------------------------------------------------------------------------

PLATFORM_MODELS = {
    "rf-detr-xlarge.pth": "https://storage.googleapis.com/rfdetr/platform-licensed/rf-detr-xlarge.pth",
    "rf-detr-xxlarge.pth": "https://storage.googleapis.com/rfdetr/platform-licensed/rf-detr-xxlarge.pth",
}



# ------------------------------------------------------------------------
# RF-DETR+
# Copyright (c) 2026 Roboflow, Inc. All Rights Reserved.
# Licensed under the Platform Model License 1.0 [see LICENSE for details]
# ------------------------------------------------------------------------
"""RF-DETR+ model definitions."""

from rfdetr_plus.models.detection import RFDETR2XLarge, RFDETR2XLargeConfig, RFDETRXLarge, RFDETRXLargeConfig

__all__ = [
    "RFDETR2XLarge",
    "RFDETR2XLargeConfig",
    "RFDETRXLarge",
    "RFDETRXLargeConfig",
]
